Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3923)

Unified Diff: chrome/browser/chromeos/net/network_change_notifier_chromeos.h

Issue 11367048: This is the first pass at making GetIPConfigs asynchronous. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/net/network_change_notifier_chromeos.h
diff --git a/chrome/browser/chromeos/net/network_change_notifier_chromeos.h b/chrome/browser/chromeos/net/network_change_notifier_chromeos.h
index 95803aca721a8f75035c29580df8bd08f6fe0ca1..291ef7f9d0636dc1736784922f0f2ea9c07cd60b 100644
--- a/chrome/browser/chromeos/net/network_change_notifier_chromeos.h
+++ b/chrome/browser/chromeos/net/network_change_notifier_chromeos.h
@@ -61,8 +61,14 @@ class NetworkChangeNotifierChromeos
// is actually scheduled.
void OnOnlineStateNotificationFired();
// Updates data members that keep the track the network stack state.
void UpdateNetworkState(chromeos::NetworkLibrary* cros);
+ // Called when a network state update has completed. Updates data members that
+ // keep the track the network stack state.
+ void UpdateNetworkStateCallback(chromeos::NetworkLibrary* cros,
+ const NetworkIPConfigVector& ip_configs,
+ const std::string& hardware_address);
// Updates network connectivity state.
void UpdateConnectivityState(const chromeos::Network* network);
@@ -61,8 +61,14 @@ class NetworkChangeNotifierChromeos
// is actually scheduled.
void OnOnlineStateNotificationFired();
- // Updates data members that keep the track the network stack state.
+ // Initiates an update of data members that keep the track the network stack
+ // state.
void UpdateNetworkState(chromeos::NetworkLibrary* cros);

Powered by Google App Engine
This is Rietveld 408576698